"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var axios_1 = tslib_1.__importDefault(require("axios"));
var index_1 = require("./adapters/index");
var compatibleMethods_1 = tslib_1.__importDefault(require("./compatibleMethods"));
var helpers_1 = require("./helpers");
var methods_1 = require("./methods");
var canceller_1 = require("./canceller");
function isWxapp() {
    return typeof wx !== 'undefined' && typeof wx.request === 'function';
}
function initAjax(options) {
    var ajax = {};
    ajax.$options = options;
    // 检测wx如果没有自定义的适配器，则使用默认适配器
    var adapter = ajax.$options.adapter || (isWxapp() ? index_1.wxAdatper : undefined);
    ajax.$options.adapter = adapter;
    ajax.$engine = axios_1.default.create();
    var requestMethods = ['POST', 'PUT', 'PATCH', 'DELETE', 'GET', 'HEAD'];
    requestMethods.forEach(function (name) {
        // @ts-ignore
        ajax[name.toLocaleLowerCase()] = (0, methods_1.generateMethod)(ajax, name);
    });
    ajax.canceller = canceller_1.canceller;
    // 把ajax实例上的'request', 'interceptors'方法代理到axios上去
    (0, helpers_1.proxyAxiosMethods)(ajax, ajax.$engine);
    (0, compatibleMethods_1.default)(ajax);
    // 添加extend方法，用于扩展ajax实例
    (0, helpers_1.addInstanceExtendMethod)(ajax);
    return ajax;
}
exports.default = initAjax;
//# sourceMappingURL=index.js.map