import { addPendingRequest, checkIfHasPendingRequest, clearPendingRequest, getCachedRequest } from '../lib/duplicateRequestPrevent'
import { generateRequestHash } from '../lib/utils';

describe('generateRequestHash测试', () => {
  const config = {
    params: {
      page: 1,
      count: 10
    },
    url: 'https://test/url',
    method: 'GET'
  }
  test('相同的config生成相同的hash', () => {
    expect(generateRequestHash(config)).toBe(generateRequestHash(config))
  })
  test('不同的config生成不同的hash', () => {
    const config2 = { ...config, method: 'POST' }
    expect(generateRequestHash(config)).not.toBe(generateRequestHash(config2))
  })
})

describe('addPendingRequest测试', () => {
  test('添加删除测试', () => {
    addPendingRequest('123', Promise.resolve({a: 1}))
    expect(getCachedRequest('123')).toEqual(Promise.resolve({a: 1}))
    expect(checkIfHasPendingRequest('123')).toBe(true)
    clearPendingRequest('123')
    expect(getCachedRequest('123')).toBeUndefined()
    expect(checkIfHasPendingRequest('123')).toBe(false)
  })
  test('超时删除测试', (done) => {
    addPendingRequest('123', Promise.resolve({a: 1}))
    expect(getCachedRequest('123')).toEqual(Promise.resolve({a: 1}))
    setTimeout(() => {
      expect(getCachedRequest('123')).toBeUndefined()
      done()
    }, 600)
  })
})