import { addInstanceExtendMethod, normalizeConfig, proxyAxiosMethods } from '../lib/helpers'
import qs from 'qs'
import type { AjaxInstance } from '../lib/types.d'

describe('标准化Ajax配置函数normalizeConfig测试', () => {
  const baseConfig = {
    headers: {},
    data: {
      data1: 1,
      data2: false,
      data3: 'str'
    },
    baseUrl: 'https://base/url',
    sendFormData: false
  }
  const context = {
    $options: {}
  }
  test('发送JSON格式数据', () => {
    const newConfig = normalizeConfig(context as AjaxInstance, baseConfig)
    expect(newConfig.headers['content-type']).toBe('application/json')
  })
  test('发送FormData格式数据', () => {
    const copyConfig = {
      ...baseConfig,
      sendFormData: true
    }
    const newConfig = normalizeConfig(context as AjaxInstance, copyConfig)
    expect(newConfig.headers['content-type']).toBe('application/x-www-form-urlencoded')
    expect(newConfig.data).toEqual(qs.stringify(copyConfig.data))
  })
  test('baseUrl和baseURL兼容', () => {
    const newConfig = normalizeConfig(context as AjaxInstance, baseConfig)
    expect(newConfig.baseURL).not.toBeUndefined()
  })
})

describe('设置代理函数proxyAxiosMethods测试', () => {
  let target: Record<string, any>, source: { request: any, interceptors: any}
  beforeEach(() => {
    target = {} as any
    source = {
      request: {a: 1},
      interceptors: {b: 1}
    }
  });
  test('代理测试', () => {
    proxyAxiosMethods(target, source)
    expect(target.request).not.toBeUndefined()
    expect(target.interceptors).not.toBeUndefined()
  })
  test('不可写测试', () => {
    proxyAxiosMethods(target, source)
    expect(() => {target.request = {}}).toThrow()
    expect(() => {target.interceptors = {}}).toThrow()
  })
})

describe('addInstanceExtendMethod测试', () => {
  test('添加extend函数测试', () => {
    const ctx: any = {}
    const source = {
      testFn: jest.fn(),
      testAttr: 'tst'
    }
    addInstanceExtendMethod(ctx)
    expect(typeof ctx.extend).toBe('function')
    ctx.extend(source)
    ctx.testFn()
    expect(source.testFn).toHaveBeenCalled()
    expect(ctx.testAttr).toBe('tst')
  })
})