import { isAbsoluteURL, combineURLs, buildFullPath, deepCopy, getType } from '../lib/utils'

describe('isAbsoluteURL test', () => {
  test('absolute url test', () => {
    expect(isAbsoluteURL('https://abs/url')).toBe(true)
    expect(isAbsoluteURL('//abs/url')).toBe(true)
  })
  test('relative url test', () => {
    expect(isAbsoluteURL('./rel/url')).toBe(false)
    expect(isAbsoluteURL('/rel/url')).toBe(false)
    expect(isAbsoluteURL('rel/url')).toBe(false)
  })
})

describe('combineURLs test', () => {
  test('combineURLs', () => {
    expect(combineURLs('/base/url', 'rel/url')).toBe('/base/url/rel/url')
    expect(combineURLs('/base/url', '/rel/url')).toBe('/base/url/rel/url')
    expect(combineURLs('/base/url/', '/rel/url')).toBe('/base/url/rel/url')
    expect(combineURLs('/base/url/', 'rel/url')).toBe('/base/url/rel/url')
    expect(combineURLs('/base/url/')).toBe('/base/url/')
  })
})

describe('buildFullPath test', () => {
  test('buildFullPath', () => {
    expect(buildFullPath('/base/url', 'rel/url')).toBe('/base/url/rel/url')
    expect(buildFullPath('', '/rel/url')).toBe('/rel/url')
    expect(buildFullPath('/base/url', 'https://rel/url')).toBe('https://rel/url')
  })
})

describe('deepCopy test', () => {
  test('deep copy none object', () => {
    expect(deepCopy(null)).toBeNull()
    expect(deepCopy('str')).toBe('str')
    expect(deepCopy(1)).toBe(1)
    expect(deepCopy(true)).toBe(true)
  })
  test('base use case', () => {
    expect(deepCopy({a: 1, b: 2})).toEqual({a: 1, b: 2})
    expect(deepCopy([1,2,'1'])).toEqual([1, 2, '1'])
  })
  test('nested object copy', () => {
    const obj = {
      a: 1,
      b: {
        ba: {
          baa: 'str',
          bab: [1, 2, { a: 1}]
        }
      },
      c: [1, 2, {b: 1}, [3, 4, 'str']]
    }
    expect(deepCopy(obj)).toEqual(obj)
  })
})

describe('getType test', () => {
  test('getType', () => {
    expect(getType(null)).toBe('null')
    expect(getType(undefined)).toBe('undefined')
    expect(getType([])).toBe('array')
    expect(getType({})).toBe('object')
    expect(getType(1)).toBe('number')
    expect(getType('')).toBe('string')
  })
})